@@ -16,6 +16,8 @@ public class CDFReader extends GenericReader {
     }
     /**
      * Constructs a reader for the given CDF file.
+     * @param    cdfFile   the cdf file name
+     * @exception CDFException.ReaderError If there was a problem
      */
     public CDFReader(String cdfFile) throws CDFException.ReaderError {
         super(cdfFile);
@@ -27,6 +29,8 @@ public class CDFReader extends GenericReader {
 
     /**
      * Constructs a reader for the given URL for CDF file.
+     * @param    url   the URL for CDF file
+     * @exception CDFException.ReaderError If there was a problem
      */
     public CDFReader(URL url) throws CDFException.ReaderError {
         super(url);
@@ -40,6 +44,9 @@ public class CDFReader extends GenericReader {
     /**
      * Returns {@link TimeSeries TimeSeries} of the specified variable
      * using the default {@link TimeInstantModel time instant model}.
+     * @param    varName   variable name
+     * @return A time series object
+     * @exception CDFException.ReaderError If there was a problem
      */
     public TimeSeries getTimeSeries(String varName) throws
         CDFException.ReaderError {
@@ -52,6 +59,8 @@ public class CDFReader extends GenericReader {
      * @param    varName   variable name
      * @param    tspec  {@link TimeInstantModel time instant model}, May be
      * null, in which case the default model is used.
+     * @return A time series object
+     * @exception CDFException.ReaderError If there was a problem
      */
     public TimeSeries getTimeSeries(String varName, TimeInstantModel tspec)
         throws CDFException.ReaderError {
@@ -72,6 +81,8 @@ public class CDFReader extends GenericReader {
      *  month (January is 1),
      * day,hour, minute, second and millisecond. May be null, in which case
      * the stop time is assumed to be later than the last available time.
+     * @return A time series object
+     * @throws CDFException.ReaderError if not a valid variable name.
      */
     public TimeSeries getTimeSeries(String varName, int[] startTime,
         int[] stopTime) throws CDFException.ReaderError {
@@ -107,6 +118,7 @@ public class CDFReader extends GenericReader {
      * @param    tspec  {@link TimeInstantModel time instant model}, May be
      * null, in which case the default model is used.
      * @return   {@link TimeSeries time series}
+     * @throws CDFException.ReaderError if not a valid variable name.
      */
     public TimeSeries getTimeSeries(String varName, int[] startTime,
         int[] stopTime, TimeInstantModel tspec) throws
@@ -161,6 +173,7 @@ public class CDFReader extends GenericReader {
      * @param    columnMajor specifies whether the first index of the
      * variable dimension varies the fastest, i.e. IDL like.
      * @return   {@link TimeSeriesOneD time series}
+     * @throws CDFException.ReaderError if not a valid variable name.
      */
     public TimeSeriesOneD getTimeSeriesOneD(String varName, int[] startTime,
         int[] stopTime, TimeInstantModel tspec, boolean columnMajor) throws
@@ -192,6 +205,7 @@ public class CDFReader extends GenericReader {
      * @param    varName   variable name
      * @return   double[2] 0th element is the first available offset time; 
      *                     1st element is the last available offset time; 
+     * @throws CDFException.ReaderError if not a valid variable name.
      */
     public double [] getAvailableTimeRange(String varName) throws
         CDFException.ReaderError {
@@ -213,6 +227,7 @@ public class CDFReader extends GenericReader {
     /**
      * Returns first available time for a variable.
      * Returned time has millisecond precision.
+     * @param varName the variable name
      * @return  int[7] containing year, month, day, hour, minute, second and
      * millisecond, or null.
      * @throws CDFException.ReaderError if not a valid variable name.
@@ -226,6 +241,7 @@ public class CDFReader extends GenericReader {
      * Returns first available time which is not before the given time for a
      * variable.
      * Returned time has millisecond precision.
+     * @param varName the variable name
      * @param start a 3 to 7 element int[], containing year,
      *  month (January is 1), day, hour, minute, second and millisecond.
      * @return  int[7] containing year, month, day, hour, minute, second and
@@ -264,6 +280,7 @@ public class CDFReader extends GenericReader {
     /**
      * Returns last available time for a variable.
      * Returned time has millisecond precision.
+     * @param varName the variable name
      * @return  int[7] containing year, month, day, hour, minute, second and
      * millisecond, or null.
      * @throws CDFException.ReaderError if not a valid variable name.
@@ -277,6 +294,7 @@ public class CDFReader extends GenericReader {
      * Returns last available time which is not later than the given time
      * for a variable.
      * Returned time has millisecond precision.
+     * @param varName the variable name
      * @param stop a 3 to 7 element int[], containing year,
      *  month (January is 1), day, hour, minute, second and millisecond.
      * @return  int[7] containing year, month, day, hour, minute, second and
@@ -326,6 +344,9 @@ public class CDFReader extends GenericReader {
      * @param baseTime a 3 to 7 element int[], containing year,
      *  month (January is 1),
      * day,hour, minute, second and millisecond.
+     * @return A TimeInstantModel object 
+     * @throws CDFException.ReaderError if not a valid variable name or
+     *                                  incomplete base time.
      */
     public TimeInstantModel timeModelInstance(String varName, int[] baseTime)
         throws CDFException.ReaderError {
@@ -351,6 +372,10 @@ public class CDFReader extends GenericReader {
      * @param baseTime a 3 to 7 element int[], containing year,
      *  month (January is 1),
      * day,hour, minute, second and millisecond.
+     * @param offsetUnits offset units in milliseconds
+     * @return A TimeInstantModel object 
+     * @throws CDFException.ReaderError if not a valid variable name or
+     *                                  incomplete base time.
      */
     public TimeInstantModel timeModelInstance(String varName, int[] baseTime,
         TimePrecision offsetUnits) throws CDFException.ReaderError {
@@ -378,6 +403,7 @@ public class CDFReader extends GenericReader {
      * Returns default {@link TimeInstantModel time instant model}.
      * <p>
      * The base of default TimeInstantModel is January 1,1970 0:0:0
+     * @return A TimeInstantModel object
      */
     public static TimeInstantModel timeModelInstance() {
         return TimeVariableFactory.getDefaultTimeInstantModel();
@@ -388,6 +414,8 @@ public class CDFReader extends GenericReader {
      * given units for the offset..
      * <p>
      * The base of default TimeInstantModel is January 1,1970 0:0:0
+     * @param offsetUnits offset units in milliseconds
+     * @return A TimeInstantModel object
      */
     public static TimeInstantModel timeModelInstance(String offsetUnits) {
         TimeInstantModel tim = TimeVariableFactory.getDefaultTimeInstantModel();
@@ -438,7 +466,9 @@ public class CDFReader extends GenericReader {
 
     /**
      * Returns names of variables that the specified  variable depends on.
-     * @return String[] 
+     * @param varName the variable name
+     * @return a string array of variable names that the given variable 
+     *         depends on.
      */
     public String[] getDependent(String varName) {
         String[] anames = thisCDF.variableAttributeNames(varName);
@@ -458,8 +488,10 @@ public class CDFReader extends GenericReader {
      * Returns the name of the specified index of a multi-dimensional
      * variable
      * @param    varName   variable name
-     * @param    index     index whose name is required
-     * @return  String
+     * @param    index     index to a multi-dimensional variable
+     * @return   the name of the variable corresponding to the index that
+     *           the given variable depends on
+     @throws   CDFException.ReaderError  if there is an error
      */
     public String getIndexName(String varName, int index) throws
         CDFException.ReaderError {
@@ -484,6 +516,8 @@ public class CDFReader extends GenericReader {
      * variable via the FILLVAL attribute, then points where the value is
      * equal to fill value are excluded.
      * </p>
+     * @param    varName   variable name
+     * @return   2-D double with times and values
      * @throws   CDFException.ReaderError  if variables is non-numeric, or
      * is not a scalar.
      */
@@ -510,6 +544,7 @@ public class CDFReader extends GenericReader {
      * </p>
      * For numeric variables of dimension other than 0, and for
      * character string variables an  exception is thrown.
+     * @param    varName   variable name
      * @param    startTime   a 3 to 7 element int[], containing year,
      *  month (January is 1),
      * day,hour, minute, second and millisecond. May be null, in which case
@@ -518,6 +553,7 @@ public class CDFReader extends GenericReader {
      *  month (January is 1),
      * day,hour, minute, second and millisecond. May be null, in which case
      * the stop time is assumed to be later than the last available time.
+     * @return   2-D double with times and values
      * @throws   CDFException.ReaderError  if variables is non-numeric, or
      * is not a scalar.
      */
@@ -540,6 +576,7 @@ public class CDFReader extends GenericReader {
      * attribute, then points where the value is equal to fill value are
      * excluded.
      * </p>
+     * @param    varName  the variable name
      * @param    startTime   a 3 to 7 element int[], containing year,
      *  month (January is 1),
      * day,hour, minute, second and millisecond. May be null, in which case
@@ -550,6 +587,7 @@ public class CDFReader extends GenericReader {
      * the stop time is assumed to be later than the last available time.
      * @param    tspec  {@link TimeInstantModel time instant model}, May be
      * null, in which case the default model is used.
+     * @return   A TimeSeries object 
      * @throws   CDFException.ReaderError  if variables is non-numeric, or
      * is not a scalar.
      */
@@ -573,6 +611,9 @@ public class CDFReader extends GenericReader {
      * variable via the FILLVAL attribute, then points where the value is
      * equal to fill value are excluded if ignoreFill = true.
      * </p>
+     * @param varName the variable name
+     * @param ignoreFill A flag indicating whether to ignore the FILLVAL value
+     * @return   A 2-D double with times and values
      * @throws   CDFException.ReaderError  if variables is non-numeric, or
      * is not a scalar.
      */
@@ -597,6 +638,8 @@ public class CDFReader extends GenericReader {
      * attribute, then if ignoreFill has the value true, points where the
      * value is equal to fill value are excluded if ignoreFill = true.
      * </p>
+     * @param varName the variable name
+     * @param ignoreFill A flag indicating whether to ignore the FILLVAL value
      * @param    startTime   a 3 to 7 element int[], containing year,
      *  month (January is 1),
      * day,hour, minute, second and millisecond. May be null, in which case
@@ -605,6 +648,7 @@ public class CDFReader extends GenericReader {
      *  month (January is 1),
      * day,hour, minute, second and millisecond. May be null, in which case
      * the stop time is assumed to be later than the last available time.
+     * @return   A 2-D double with times and values
      * @throws   CDFException.ReaderError  if variables is non-numeric, or
      * is not a scalar.
      */
@@ -629,6 +673,8 @@ public class CDFReader extends GenericReader {
      * attribute, then if ignoreFill has the value true, points where the
      * value is equal to fill value are excluded if ignoreFill = true.
      * </p>
+     * @param varName the variable name
+     * @param ignoreFill A flag indicating whether to ignore the FILLVAL value
      * @param    startTime   a 3 to 7 element int[], containing year,
      *  month (January is 1),
      * day,hour, minute, second and millisecond. May be null, in which case
@@ -639,6 +685,7 @@ public class CDFReader extends GenericReader {
      * the stop time is assumed to be later than the last available time.
      * @param    tspec  {@link TimeInstantModel time instant model}, May be
      * null, in which case the default model is used.
+     * @return  A TimeSeries object
      * @throws   CDFException.ReaderError  if variables is non-numeric, or
      * is not a scalar.
      */
@@ -743,6 +790,9 @@ public class CDFReader extends GenericReader {
      * variable via the FILLVAL attribute, then points where the value is
      * equal to fill value are excluded.
      * </p>
+     * @param varName the variable name
+     * @param component The component in 1-D array
+     * @return   A 2-D double containing times and values
      * @throws   CDFException.ReaderError  if variables is non-numeric, or is
      * not a vector.
      */
@@ -766,6 +816,8 @@ public class CDFReader extends GenericReader {
      * variable via the FILLVAL attribute, then points where the value is
      * equal to fill value are excluded.
      * </p>
+     * @param varName the variable name
+     * @param component The component in 1-D array
      * @param    startTime   a 3 to 7 element int[], containing year,
      *  month (January is 1),
      * day,hour, minute, second and millisecond. May be null, in which case
@@ -774,6 +826,7 @@ public class CDFReader extends GenericReader {
      *  month (January is 1),
      * day,hour, minute, second and millisecond. May be null, in which case
      * the stop time is assumed to be later than the last available time.
+     * @return   A 2-D double containing times and values
      * @throws   CDFException.ReaderError  if variables is non-numeric, or is
      * not a vector.
      */
@@ -811,6 +864,7 @@ public class CDFReader extends GenericReader {
      * the stop time is assumed to be later than the last available time.
      * @param    tspec  {@link TimeInstantModel time instant model}, May be
      * null, in which case the default model is used.
+     * @return   A TimeSeries object
      * @throws   CDFException.ReaderError  if variables is non-numeric, or is
      * not a vector.
      */
@@ -835,6 +889,11 @@ public class CDFReader extends GenericReader {
      * variable via the FILLVAL attribute, then points where the value is
      * equal to fill value are excluded if ignoreFill = true.
      * </p>
+     * @param    varName   variable name
+     * @param    component   index of the vector component
+     * @param    ignoreFill A flag indicating whether to ingore the FILLVAL
+     *                      value
+     * @return   A 2-D double containing times and values
      * @throws   CDFException.ReaderError  if variables is non-numeric, or is
      * not a vector.
      */
@@ -858,6 +917,10 @@ public class CDFReader extends GenericReader {
      * variable via the FILLVAL attribute, then points where the value is
      * equal to fill value are excluded if ignoreFill = true.
      * </p>
+     * @param    varName   variable name
+     * @param    component   index of the vector component
+     * @param    ignoreFill A flag indicating whether to ingore the FILLVAL
+     *                      value
      * @param    startTime   a 3 to 7 element int[], containing year,
      *  month (January is 1),
      * day,hour, minute, second and millisecond.
@@ -865,6 +928,7 @@ public class CDFReader extends GenericReader {
      *  month (January is 1),
      * day,hour, minute, second and millisecond. May be null, in which case
      * the stop time is assumed to be later than the last available time.
+     * @return   A 2-D double containing times and values
      * @throws   CDFException.ReaderError  if variables is non-numeric, or is
      * not a vector.
      */
@@ -892,6 +956,9 @@ public class CDFReader extends GenericReader {
      * value is equal to fill value are excluded if ignoreFill = true.
      * </p>
      * @param    varName   variable name
+     * @param    component   index of the vector component
+     * @param    ignoreFill A flag indicating whether to ingore the FILLVAL
+     *                      value
      * @param    startTime   a 3 to 7 element int[], containing year,
      *  month (January is 1),
      * day,hour, minute, second and millisecond. May be null, in which case
@@ -902,6 +969,7 @@ public class CDFReader extends GenericReader {
      * the stop time is assumed to be later than the last available time.
      * @param    tspec  {@link TimeInstantModel time instant model}, May be
      * null, in which case the default model is used.
+     * @return  A TimeSeries object
      * @throws   CDFException.ReaderError  if variables is non-numeric, or
      * is not a vector.
      * Use {@link #getTimeSeries(String varName) getTimeSeries(
